# Default provider build options (MySQL, Postgres & unixODBC)
#
# Package build options:
# --without tds
# --without db2
# --without oracle
# --with sqlite
# --without sybase
# --without mdb
# --with ldap
# --with xbase
# --with mysql
# --with odbc
# --with postgres
# 

%define FREETDS  0
%define IBMDB2   0
%define MYSQL    1
%define ODBC     1
%define ORACLE   0
%define POSTGRES 1
%define SQLITE   1
%define SYBASE   0
%define MDB      0
%define LDAP     1
%define XBASE    1

%{?_with_tds:%define FREETDS 1}
%{?_with_db2:%define IBMDB2 1}
%{?_without_ldap:%define LDAP 0}
%{?_with_mdb:%define MDB 1}
%{?_with_oracle:%define ORACLE 1}
%{?_without_sqlite:%define SQLITE 0}
%{?_with_sybase:%define SYBASE 1}
%{?_without_mysql:%define MYSQL 0}
%{?_without_odbc:%define ODBC 0}
%{?_without_xbase:%define XBASE 0}
%{?_without_postgres:%define POSTGRES 0}

Summary:          Library for writing gnome database programs
Name:             compat-libgda
Version:          1.2.3
Release:          4%{?dist}
Source:           http://ftp.gnome.org/pub/GNOME/sources/libgda/1.2/libgda-%{version}.tar.bz2
URL:              http://www.gnome-db.org/
Group:            System Environment/Libraries
License:          LGPL
BuildRoot:        %{_tmppath}/%{name}-%{version}-root
BuildRequires:    pkgconfig >= 0.8
Requires:         glib2 >= 2.0.0
Requires:         libxslt >= 1.0.9
Requires:         ncurses
BuildRequires:    glib2-devel >= 2.0.0
BuildRequires:    libxml2-devel
BuildRequires:    libxslt-devel >= 1.0.9
BuildRequires:    ncurses-devel
BuildRequires:    scrollkeeper gettext intltool
BuildRequires:    groff
BuildRequires:    readline-devel
BuildRequires:    db4-devel
BuildRequires:    automake autoconf libtool gtk-doc

%if %{FREETDS}
BuildRequires:    freetds-devel
%endif

%if %{MYSQL}
BuildRequires:    mysqlclient10-devel
%endif

%if %{POSTGRES}
BuildRequires:    postgresql-devel
%endif

%if %{ODBC}
BuildRequires:    unixODBC-devel
%endif

%if %{SQLITE}
BuildRequires:    sqlite-devel
%endif

%if %{MDB}
BuildRequires:    mdbtools-devel
%endif

%if %{LDAP}
BuildRequires:    openldap-devel
%endif

%if %{XBASE}
BuildRequires:    xbase-devel
%endif

Patch0: libgda-1.2.0-configure.patch
Patch1: libgda-1.2.3-gdasql.patch
Patch2: libgda-1.2.3-configpath.patch

%description
libgda is a library that eases the task of writing
gnome database programs.


%package devel
Summary:          Development libraries and header files for libgda
Group:            Development/Libraries
Requires:         glib2-devel >= 2.0.0
Requires:         libxml2-devel
Requires:         libxslt-devel >= 1.0.9
Requires:         db4-devel
Requires:         %{name} = %{version}-%{release}

%description devel
This package contains the header files and libraries needed to write
or compile programs that use libgda.

%if %{FREETDS}
%package -n compat-gda-freetds
Summary:        GDA FreeTDS Provider
Group:          System Environment/Libraries
License:	GPL
%description -n compat-gda-freetds
This package includes the GDA FreeTDS provider.
%endif

%if %{IBMDB2}
%package -n compat-gda-ibmdb2
Summary:        GDA IBM DB2 Provider
Group:          System Environment/Libraries
License:	GPL
%description -n compat-gda-ibmdb2
This package includes the GDA IBM DB2 provider.
%endif

%if %{MYSQL}
%package -n compat-gda-mysql
Summary:        GDA MySQL Provider
Group:          System Environment/Libraries
License:	GPL
%description -n compat-gda-mysql
This package includes the GDA MySQL provider.
%endif

%if %{ODBC}
%package -n compat-gda-odbc
Summary:        GDA ODBC Provider
Group:          System Environment/Libraries
License:	GPL
%description -n compat-gda-odbc
This package includes the GDA ODBC provider.
%endif

%if %{ORACLE}
%package -n compat-gda-oracle
Summary:        GDA Oracle Provider
Group:          System Environment/Libraries
License:	GPL
%description -n compat-gda-oracle
This package includes the GDA Oracle provider.
%endif

%if %{POSTGRES}
%package -n compat-gda-postgres
Summary:        GDA PostgreSQL Provider
Group:          System Environment/Libraries
License:	GPL
%description -n compat-gda-postgres
This package includes the GDA PostgreSQL provider.
%endif

%if %{SQLITE}
%package -n compat-gda-sqlite
Summary:        GDA SQLite Provider
Group:          System Environment/Libraries
License:	GPL
%description -n compat-gda-sqlite
This package includes the GDA SQLite provider.
%endif

%if %{SYBASE}
%package -n compat-gda-sybase
Summary:        GDA Sybase Provider
Group:          System Environment/Libraries
License:	GPL
%description -n compat-gda-sybase
This package includes the GDA Sybase provider.
%endif

%if %{MDB}
%package -n compat-gda-mdb
Summary:        GDA MDB Provider
Group:          System Environment/Libraries
License:	GPL
%description -n compat-gda-mdb
This package includes the GDA MDB provider.
%endif

%if %{LDAP}
%package -n compat-gda-ldap
Summary:        GDA LDAP Provider
Group:          System Environment/Libraries
License:	GPL
%description -n compat-gda-ldap
This package includes the GDA LDAP provider.
%endif

%if %{XBASE}
%package -n compat-gda-xbase
Summary:        GDA XBASE Provider
Group:          System Environment/Libraries
License:	GPL
%description -n compat-gda-xbase
This package includes the GDA XBASE provider.
%endif

%prep
%setup -q -n libgda-%{version}
%patch0 -p1 -b .configure
%patch1 -p1 -b .gdasql
%patch2 -p1 -b .config

%build
aclocal
automake
autoconf
%if %{FREETDS}
CONFIG="$CONFIG --with-tds"
%else
CONFIG="$CONFIG --without-tds"
%endif

%if %{IBMDB2}
CONFIG="$CONFIG --with-ibmdb2"
%else
CONFIG="$CONFIG --without-ibmdb2"
%endif

%if %{MYSQL}
CONFIG="$CONFIG --with-mysql"
%else
CONFIG="$CONFIG --without-mysql"
%endif

%if %{POSTGRES}
CONFIG="$CONFIG --with-postgres"
%else
CONFIG="$CONFIG --without-postgres"
%endif

%if %{ODBC}
CONFIG="$CONFIG --with-odbc"
%else
CONFIG="$CONFIG --without-odbc"
%endif

%if %{ORACLE}
CONFIG="$CONFIG --with-oracle"
%else
CONFIG="$CONFIG --without-oracle"
%endif

%if %{SQLITE}
CONFIG="$CONFIG --with-sqlite"
%else
CONFIG="$CONFIG --without-sqlite"
%endif

%if %{SYBASE}
CONFIG="$CONFIG --with-sybase"
%else
CONFIG="$CONFIG --without-sybase"
%endif

%if %{MDB}
CONFIG="$CONFIG --with-mdb"
%else
CONFIG="$CONFIG --without-mdb"
%endif

%if %{LDAP}
CONFIG="$CONFIG --with-ldap"
%else
CONFIG="$CONFIG --without-ldap"
%endif

%if %{XBASE}
CONFIG="$CONFIG --with-xbase"
%else
CONFIG="$CONFIG --without-xbase"
%endif

%configure $CONFIG --disable-static --disable-gtk-doc
make %{?_smp_mflags}

%install
make install DESTDIR=$RPM_BUILD_ROOT
find $RPM_BUILD_ROOT -type f -name "*.la" -exec rm -f {} ';'
# Need to set these exectutable so that they get stripped into debuginfo
chmod +x $RPM_BUILD_ROOT%{_libdir}/lib*.so.*
chmod +x $RPM_BUILD_ROOT%{_libdir}/libgda/providers/libgda-*

rm -fr $RPM_BUILD_ROOT%{_datadir}/gtk-doc
rm -fr $RPM_BUILD_ROOT%{_datadir}/omf
rm -fr $RPM_BUILD_ROOT%{_bindir}
rm -fr $RPM_BUILD_ROOT%{_mandir}
rm -fr $RPM_BUILD_ROOT%{_datadir}/libgda

%find_lang libgda-2

%post -p /sbin/ldconfig


%postun -p /sbin/ldconfig


%clean
rm -rf $RPM_BUILD_ROOT


%files -f libgda-2.lang
%defattr(-,root,root)
%doc AUTHORS COPYING COPYING.LIB ChangeLog README NEWS

%dir %{_sysconfdir}/compat-libgda
%config(noreplace) %{_sysconfdir}/compat-libgda/config
%{_libdir}/*.so.*
%dir %{_libdir}/libgda
%dir %{_libdir}/libgda/providers
%{_libdir}/libgda/providers/libgda-xml.so
%{_libdir}/libgda/providers/libgda-bdb.so

%files devel
%defattr(-,root,root)
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/*

%if %{FREETDS}
%files -n compat-gda-freetds
%defattr(-,root,root)
%{_libdir}/libgda/providers/libgda-freetds.so
%endif

%if %{IBMDB2}
%files -n compat-gda-ibmdb2
%defattr(-,root,root)
%{_libdir}/libgda/providers/libgda-ibmdb2.so
%endif

%if %{MYSQL}
%files -n compat-gda-mysql
%defattr(-,root,root)
%{_libdir}/libgda/providers/libgda-mysql.so
%endif

%if %{ODBC}
%files -n compat-gda-odbc
%defattr(-,root,root)
%{_libdir}/libgda/providers/libgda-odbc.so
%endif

%if %{ORACLE}
%files -n compat-gda-oracle
%defattr(-,root,root)
%{_libdir}/libgda/providers/libgda-oracle.so
%endif

%if %{POSTGRES}
%files -n compat-gda-postgres
%defattr(-,root,root)
%{_libdir}/libgda/providers/libgda-postgres.so
%endif

%if %{SQLITE}
%files -n compat-gda-sqlite
%defattr(-,root,root)
%{_libdir}/libgda/providers/libgda-sqlite.so
%endif

%if %{SYBASE}
%files -n compat-gda-sybase
%defattr(-,root,root)
%{_libdir}/libgda/providers/libgda-sybase.so
%endif

%if %{MDB}
%files -n compat-gda-mdb
%defattr(-,root,root)
%{_libdir}/libgda/providers/libgda-mdb.so
%endif

%if %{LDAP}
%files -n compat-gda-ldap
%defattr(-,root,root)
%{_libdir}/libgda/providers/libgda-ldap.so
%endif

%if %{XBASE}
%files -n compat-gda-xbase
%defattr(-,root,root)
%{_libdir}/libgda/providers/libgda-xbase.so
%endif


%changelog
* Mon Sep 11 2006 Denis Leroy <denis@poolshark.org> - 1.2.3-4
- Added intltool BR

* Mon Sep 11 2006 Tom "spot" Callaway <tcallawa@redhat.com> - 1.2.3-3
- add xbase
- enable everything we can by default (they're subpackages)
- make sure all the libs get stripped into debuginfo
- use URL to Source0
- use correct license tags

* Mon Jul 24 2006 Denis Leroy <denis@poolshark.org> - 1.2.3-2
- Fixed compat configuration directory

* Wed Jul  5 2006 Denis Leroy <denis@poolshark.org> - 1.2.3-1
- First draft, based on FC-4 libgda.spec

